eventmond(1M)

eventmond - system event monitoring daemon

As shipped in IRIX 6.5.19. Added in IRIX 6.5.5.

NAME
     eventmond - system event monitoring daemon

SYNOPSIS
      eventmond [-a on|off] [-u timestamp_fname]
      [-j tout_sec] [-e tout_hours]
      [-o eventlogfile] [-d] [-q] [-r] [-l]
      [-f maxfiles] [-b maxbuffers][-t tablename]
      [-n dbname] [-w dblib_name] [-m maxreptcnt]
      [-x on|off] [-i] [-v] [-c] [-h]


DESCRIPTION
     eventmond runs at system startup, collects system events from syslogd,
     esplogger or any other application that interacts with EventmonAPI (see
     EventmonAPI(3X) for more details), and passes such system events directly
     to the SGI Embedded Support Partner (a.k.a ESP; see esp(5) for more
     details) framework. In case SGI ESP Support Data Base server is not
     running or SGI ESP Event Manager is not running, eventmond will buffer
     events. Whenever rate of the incoming events is higher than ability of
     the system to process such events, eventmond also buffers overhead of
     event messages. On condition that capacity of buffers is exhausted
     eventmond stores event messages in temporary files. Eventmond is called
     by during the system startup process by init  which runs
     /etc/init.d/eventmonitor script which in turn is called by
     /etc/init.d/sysetup script. It is not recommended to execute eventmond
     manually. Eventmond can be executed in two alternative modes - daemon
     mode and application mode. As an application eventmond provides access
     and particular controls with respect to the instance of eventmon daemon
     currently residing in memory.  In order to run eventmon in the daemon
     mode user must have root privileges. Some flags of the application mode
     demand a root privileges to perform a particular functionality.
     Eventmond also records system uptime in timestamp_fname every tout_sec
     seconds.  This information is used to estimate uptime in case of a system
     hang.  This functionality is enabled by command string option -a on.  If
     command string key -e has a non-zero value, eventmond will send availmon
     status update report every tout_hours hours.




OPTIONS
     All following flags are case insensitive.

     -a on|off
          This option is used for turning on/off ability of eventmond
          to write a time stamps into the timestamp_fname file.
          The time stamp is used by SGI ESP availmon module to estimate
          uptime in case of a system hang.

          User must have a root privileges in order to be able to use
          this option.  This option is valid in both - deamon and application
          mode.  In case eventmon daemon starts whithout this option the
          "update of time stamp file" is "off" by default.
          As an application eventmond, started with "-a" option,
          has ability to turn on/off the "update of time stamp file"
          in the existing instance of the eventmon daemon.
          This option effects -u, -j and -e options which
          perform their functionality only in case "-a" option is
          started with the "on" parameter.

     -u timestamp_fname
          This option is used to set the "time stamp" file name which by
          default is /var/adm/avail/.save/lasttick.  Option can be used
          only with the root priveleges and is valid only for the deamon mode.

          The functionality of this key (as well as functionality of
          -e and -j keys) depends on the -a key and can be in
          effect only upon condition of -a on key executed.

     -j tout_sec
          This option is used to set time out in seconds
          between "time stamp" file updates (see options -a and
          -u). This option is valid in both - deamon and application
          mode. In case eventmon daemon starts whithout this option
          the "update of time stamp file time out" is 300 seconds by
          default. As an application eventmond, started with -j option,
          has ability to change the time out in the existing
          instance of the eventmon daemon.

          It should be mentioned that functionality of this key (as
          well as functionality of -e and -u keys) depends on the
          -a key and can be in effect only upon condition of -a on
          key executed.

     -e tout_hours
          This option is used to set time interval for invoking
          amdiag script. The time interval is measured in hours.
          This option is valid in both - deamon and application mode.
          In case eventmon daemon starts whithout this option
          the time interval is 1440 hours by default.
          As an application eventmond, started with -e option,
          has ability to change the time interval in the existing
          instance of the eventmon daemon.

          In case -e key is used with "0" parameter the invoking
          of amdiag script is disabled.

          It should be mentioned that functionality of this key (as
          well as functionality of -j and -u keys) depends on the
          -a key and can be in effect only upon condition of -a on
          key executed.

     -o eventlogfile
          This option is used for saving all incoming events to
          the eventlogfile. Due to the specific daemon attributes
          eventlogfile should be expected to appear in a root
          directory unless eventlogfile name is absolute.
          One should exercise this option only with the root
          privileges.


     -d
          Eventmond starts in "Debug" mode, does not release
          controlling terminal and displays information about
          running process. In this particular case eventmon daemon
          does not change current directory to root directory.


     -q
          Eventmond starts in application mode and sends a message to
          exit to the currently running instance of eventmon daemon.
          After eventmon daemon gets a message it suppose to exit
          in a normal fashion. Eventmond application exits itself right
          after sending a message to a daemon.

          Keywords -stop or -kill also can be used to perform
          functionality of -q flag.

     -r
          Eventmond starts in application mode, sends "reload events filter
          information" command to existing instance of the eventmon daemon
          and exits.

     -l
          Eventmond is designed to reduce number of the attempts to send
          an event by the increasing time between attempts in case of the
          failure of the system to accept such an event. This flag can be
          used in case of a need to reset timeout to the initial value in
          order to increase a number of attempts to send an event.
          Eventmond with this option starts in application mode.
          User should have root privileges to be able to execute this
          option.

     -f
          Set maximum number of temporary files for saved messages
          (no more than: 100). Each file is used to store only one
          event message.

     -b
          Set maximum number of memory buffers for saved messages
          (no more than: 200).

     -n
          This option requires a name of the database as an argument and
          could be used to preserve integrity of ESP in case default
          database name is changed. Eventmond default database name is
          "ssdb".

     -t
          This option requires a name of the table as an argument and
          could be used to preserve integrity of ESP in case default
          table name is changed. Eventmond default table name is
          "event_type".

     -w
          This option requires a name of the database support DSO module
          as an argument and used in case such a name is changed.
          Eventmond default DSO module name is "libssdbapi.so".

     -m
          Eventmond starts in a daemon mode and, in case System Event
          Manager gives a recoverable error on the particular event
          message, alter a number of attempts to send such an event
          message. Default number of attempts is 200. User can use "0"
          to specify an unlimited number of attempts.

     -x on (off)
          Eventmond writes possible error messages into the SYSLOG file
          and, by default, marks each message with the ESP tag "|$"
          as an identifier. This option enables or disables such message
          identifying in the SYSLOG file.
          In this case eventmond starts in a daemon mode.

     -i
          Eventmond starts as an application, prints eventmon statistics and
          exits. Keywords -status or -state also can be used to perform
          functionality of -i flag.

     -v
          Eventmond starts as an application, prints version information
          and exits.

     -c
          Eventmond starts as an application, prints copyright information
          and exits.

     -h
          Eventmond starts as an application, prints help information and exits.

     -g on (off)
          Eventmond starts in a daemon mode, and in case the flag is "on"
          eventmond turns off filtering of the events which came from the all
          hosts but the local one.

     -silence
          Suppress all "info"/"warning"/"error" output (default: silence mode
          is "off").


DIAGNOSTICS
     Upon successful completion value of 0 is returned. Otherwise the
     following values are returned to indicate an error:

      1         invalid parameters or only "help" output

      2         system error: fork()

      3         incorrect system parameter(s), can't start daemon

      4         killed by some system signal

      5         init data error

      6         init thread error

      7         can't _daemonize

      8         already installed

      9         can't make temp file name

     10         can't open socket

     11         can't bind socket

     12         daemon is not installed

     13         can't start daemon with non root

     14         invalid CPU command

     15         invalid FPE command

     16         can't set socket option(s)



FILES
     /usr/etc/eventmond, /etc/init.d/eventmonitor, /etc/init.d/sysetup,
     /etc/init.d/availmon


SEE ALSO
     esplogger(1), EventMonAPI(3X), availmon(5).